Zero-dependency collection
==========================

Built-in nodes in juturna offer basic functionalities for input/output
operations. Being shipped with juturna itself, they carry no extra python
dependency outside of what is already defined on a package level.
